import 'dart:io';
import 'dart:async';

import '../lib/dip_client_sdk.dart';

// following URL can be any URL that will cause upload to fail
//
const invalidUploadUrlBase = 'https://s3.ap-northeast-2.amazonaws.com/';

// following URL is not guaranteed to work. Use your own server for testing
//
const validUploadUrlBase = 'https://s3.ap-northeast-2.amazonaws.com/test.exax-dx.com/';

// files to upload. Use your own files for testing
//
const fileNames= <String>[
    'sample_960x400_ocean_with_audio.webm',
    'sample_960x540.webm',
    'TestMultiUploader.dart',
    'TestUser.dart',
    'TestResourceAndIdentity.dart',
    'TestGroup.dart',
];

var fileInfos = <UploadFile>[];

void main() async {
	for (var i = 0; i < fileNames.length; i++) {
		var file = new File(fileNames[i]);

		if (i == 0) {
			// intentional failure for testing
			fileInfos.add(new UploadFile(
				invalidUploadUrlBase + fileNames[i],
				file,
				'video',
				fileNames[i],
				await file.length(),
			));
		}
		else {
			fileInfos.add(new UploadFile(
				validUploadUrlBase + fileNames[i],
				file,
				'video',
				fileNames[i],
				await file.length(),
			));
		}
	}

	var config = <String,dynamic>{
		'maxConcurrency': 5,
		'maxRetry': 3,
		'monitorInterval': 3000,
		'cancelThreshold': 50000,
	};

	var uploader = new MultiUploader(fileInfos, config);

    print("progress = " + uploader.getProgress().toString());
    await uploader.upload();
    print("progress = " + uploader.getProgress().toString());
}
