import '../lib/dip_client_sdk.dart';

void main() async {
	var dipClient = new DipClient(DipClient.ENV_INT);
	print("dipClient created");

	var userSeqNum = await dipClient.getSeqNum(seqName: "test-user-seqnum");
	var userSeqNumStr = userSeqNum.toString();
	print("test user seqeuence number = " + userSeqNumStr);

    var userName = "test-user-" + userSeqNumStr + "@dip-test.com";
    var password = "1111";
    var name = "테스트사용자(Identity)";

    await dipClient.createUser(
        userName: userName,
        password: password,
        name: name
    );
    print("test user created: username = " + userName);

    await dipClient.authenticate(
        userName: userName,
        password: password
    );
    print("test user authenticated: username = " + userName);

	List<Map<String,dynamic>> resourcesData = [
		{
			'resourceType': 'video',
			'resourceName': 'resource1',
			'fileName': 'fileName1.mp4',
			'fileSize': 999,
			'resourceParams': {
				'isWebcam': true,
				'hflip': true,
			},
		},
		{
			'resourceType': 'video',
			'resourceName': 'resource2',
			'fileName': 'fileName2.mp4',
			'fileSize': 1111,
			'tags': [ 'test-tag' ],
		},
	];

	var resourceUrls = await dipClient.addResources(
		userName: userName,
		resources: resourcesData
	);
	print("test resources created: resourceUrls = " + resourceUrls.toString());

	List<String> resourceIds = [];
	resourceUrls.forEach((Map<String,dynamic> e) => resourceIds.add(e['resourceId'] as String));

	var resources = await dipClient.getResources(resourceIds: resourceIds);
	print("test resources retrieved: resources = " + resources.toString());

	var resourcesForTag = await dipClient.getResourcesByTag(tag: 'test-tag');
	print("test resources retrieved by tag 'test-tag': resources = " + resourcesForTag.toString());

	var identityOwner = userName;
	var identityCategory = '/test-category';
	var identityAttrs = {
		'attr1': 'attr1_value'
	};
	var identityDattrs = {
		'dattr1': 'dattr1_value'
	};
	var identityResources = {
		'video': resourceIds
	};

	var identityId = await dipClient.createIdentity(
		identityOwner: identityOwner,
		category: identityCategory,
		attrs: identityAttrs,
		dattrs: identityDattrs,
		resources: identityResources,
		isTemporary: true,
	);
	print("test identity created: identityId = " + identityId);

	var updates = [
		{
			'target': 'dattrs.message',
			'value': {
				'title': 'test title',
				'message': 'test message body'
			}
		}
	];

	await dipClient.updateIdentity(
		identityId: identityId,
		updates: updates
	);
	print("test identity updated: identityId = " + identityId);

	var accessResp = await dipClient.accessIdentity(
		identityId: identityId,
		returnValues: true
	);
	print("test identity accessed: returnValues = " + accessResp.toString());

	var identities = await dipClient.getIdentities(identityIds: [ identityId ]);
	print("test identity got: identities = " + identities.toString());

	var identitiesByUser = await dipClient.getIdentitiesByUser(userName: userName);
	print("test identity got by user: identities = " + identitiesByUser.toString());

	await dipClient.deleteIdentity(identityId: identityId);
}
